@@ -369,7 +369,7 @@ MODULE_ENTRY (fill_info) (GdkPixbufFormat *info)
 
 	info->name = "wbmp";
 	info->signature = (GdkPixbufModulePattern *) signature;
-	info->description = N_("The WBMP image format");
+	info->description = NC_("image format", "WBMP");
 	info->mime_types = (gchar **) mime_types;
 	info->extensions = (gchar **) extensions;
 	info->flags = GDK_PIXBUF_FORMAT_THREADSAFE;
